Documentation
¶
Overview ¶
Package naming defines the naming API and related data structures for gRPC. The interface is EXPERIMENTAL and may be suject to change.
Index ¶
Constants ¶
const ( // Add indicates a new address is added. Add = iota // Delete indicates an exisiting address is deleted. Delete )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Resolver ¶
type Resolver interface {
// Resolve returns the name resolution results.
Resolve(target string) ([]*Update, error)
// NewWatcher creates a Watcher to watch the changes on target.
NewWatcher(target string) Watcher
}
Resolver does one-shot name resolution and creates a Watcher to watch the future updates.
type ServiceConfig ¶
type ServiceConfig interface{}
type Update ¶
type Update struct {
// Op indicates the operation of the update.
Op OP
Addr string
Config ServiceConfig
}
Update defines a name resolution change.
Click to show internal directories.
Click to hide internal directories.